@@ -332,7 +332,7 @@ class BaseModuleManager(ABC):
                 # Resolve path to the module's directory
                 plugin_file = Path(sys.modules[plugin_class.__module__].__file__).resolve()
                 plugin_path = plugin_file.parent
-
+                package_name ='.'.join(plugin_instance.__class__.__module__.split('.')[:-1])
                 # Enabled by default, but you can still override via self.plugin_states
                 is_enabled = self.plugin_states.get(plugin_instance.module_name, True)
 
@@ -344,6 +344,7 @@ class BaseModuleManager(ABC):
                     path=plugin_path,
                     enabled=is_enabled,
                     initialized=True,
+                    package_name=package_name,
                 )
                 # plugin_state.process()
                 self.modules[plugin_instance.module_name] = plugin_state
