@@ -3,7 +3,7 @@ from typing import Optional
 
 def menu_entry(
     label: str,
-    icon: str = "fa fa-ask",
+    icon: str = "",
     parent: Optional[str] = None,
     type: str = "main",
     position: Optional[int] = None,
