@@ -20,3 +20,7 @@ def safe_render(ctx, caller):
             '</pre></div>'
         )
 
+def inject_js_global_var():
+    from fastpluggy.fastpluggy import FastPluggy
+    data = FastPluggy.get_global('js_global_var')
+    return data
\ No newline at end of file
