@@ -7,6 +7,7 @@ from fastpluggy.core.flash import FlashMessage
 from fastpluggy.core.global_registry import GlobalRegistry
 from fastpluggy.core.tools.inspect_tools import call_with_injection
 from fastpluggy.core.widgets.fastpluggy_integration import FastPluggyWidgets
+import traceback
 
 
 def inject_widgets(widgets: list, tag: str = '#ROOT#'):
@@ -164,7 +165,8 @@ class ViewBuilder:
             """
             FlashMessage.add(request, message, "warning")
 
-    def _process_widget(self, widget: Any, request: Request, **kwargs) -> Any:
+    @staticmethod
+    def _process_widget(widget: Any, request: Request, **kwargs) -> Any:
         """Process an individual widget/component."""
         
         # Inject request and db if available
