@@ -269,8 +269,14 @@ class TableWidget(AbstractWidget, RequestParamsMixin, FieldHandlingView):
         for item in self.processed_data:
             for field, callback in self.field_callbacks.items():
                 if field in item:
+                    value = item[field]
                     try:
-                        item[field] = callback(item[field])
+                        # Prefer callbacks that accept (value, row)
+                        try:
+                            item[field] = callback(value, item)
+                        except TypeError:
+                            # Fallback to legacy single-argument callbacks
+                            item[field] = callback(value)
                     except Exception as e:
                         logger.warning(f"Error applying callback for field '{field}': {e}")
                         # Keep original value on error
@@ -294,6 +300,8 @@ class TableWidget(AbstractWidget, RequestParamsMixin, FieldHandlingView):
                 if isinstance(link, BaseButtonWidget):
                     # Already a button widget - clone it for this specific item
                     link_copy = deepcopy(link)
+                    if hasattr(link_copy, "request"):
+                        link_copy.request = self.request
                     button_widgets.append(link_copy)
 
                 elif isinstance(link, dict):
